@@ -8,23 +8,26 @@ bootstrap_renyi <- function(x,
                             ly,
                             q,
                             burn = 50) {
-
   bootx <- markov_boot_step(x, lx, burn)
   booty <- markov_boot_step(y, ly, burn)
 
   # Lead = x
-  dteyx <- calc_te_renyi(x = bootx,
-                         lx = lx,
-                         y = y,
-                         ly = ly,
-                         q = q)
+  dteyx <- calc_te_renyi(
+    x = bootx,
+    lx = lx,
+    y = y,
+    ly = ly,
+    q = q
+  )
 
   # Lead = y
-  dtexy <- calc_te_renyi(x = booty,
-                         lx = ly,
-                         y = x,
-                         ly = lx,
-                         q = q)
+  dtexy <- calc_te_renyi(
+    x = booty,
+    lx = ly,
+    y = x,
+    ly = lx,
+    q = q
+  )
 
   teboot <- c(dteyx, dtexy)
   names(teboot) <- c("dteyx", "dtexy")
